#############################################################################
# rescale2actual.tcl: csurf script to make surfaces for areal measurements
#############################################################################
#
# Background:
#
# In order to avoid downsampling the original 0.19 x 0.19 x 0.19 mm image
# data set before making a surface from it in csurf, it was imported without
# resampling it, as if it were a csurf 'conforming' 512^3 data set with
# 0.50 x 0.50 x 0.50 mm voxels. Therefore, the freesurfer 3D vertex coords
# of the following surfaces:
#
#   rh.orig
#   rh.smoothwm
#   rh.inflated
#
# are larger than actual size by a factor of 0.50/0.19
#
# This script generates a properly scaled surface for areal measurements
# using the tksurfer FILL button.  The output surface has same name as
# the input surface with "-actual" appended.
#
# This script also applies a +3% volume correction for shrinkage (see
# Schulz et al., 2011).  This corresponds to a +1% linear scale factor.
#
# N.B.: the output surface will be misaligned with hi-res 3D data it was
# generated from.
#
# To run this script in csurf:
#
#   1) start csurf
#   2) select subject "cerebmap20-dentate" from csurf "subject:" dropdown
#   3) select surface-to-rescale from csurf "surface:" dropdown (e.g., "pial")
#   4) open surface in tksurfer by clicking csurf "SURFACE" button
#   5) select "rescale2actual.tcl" from upper left tksurfer "tcl:" dropdown
#        (it will be under LOCAL SUBJECT SCRIPTS)
#   6) click "GO"
#

# check/confirm overwrite output surface
if { [file exists $insurf-$outsuff] } {
  if ![okreplace "" "Output surf exists:\n\n   $insurf-$outsuff\n\nOverwrite?"\
        "Re-Scale Surface"] { return }
}

# go: rescale surface
really_scale_brain 0.38 0.38 0.38   ;# linear scale factor: 0.19/0.50 = 0.38
redraw
really_scale_brain 1.01 1.01 1.01   ;# 1% linear = 3% volume (shrinkage-correct)
redraw
setfile outsurf $insurf-actual
write_binary_surface

# done
confirmalert "rescale2actual.tcl: made veridical scaled surface:\n\n$outsurf"
unset outsuff

